@@ -83,9 +83,9 @@ class BasicTransfersViewDelegate : public KExtendableItemDelegate
     public:
         BasicTransfersViewDelegate(QAbstractItemView *parent);
 
-        virtual QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
-        virtual void setEditorData(QWidget *editor, const QModelIndex &index) const override;
-        virtual void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
+        QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+        void setEditorData(QWidget *editor, const QModelIndex &index) const override;
+        void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
 
     private slots:
         virtual void slotGroupStatusChanged(GroupStatusEditor *editor);
